@@ -29,6 +29,11 @@ main(int argc, char **argv)
 
     std::cout << "Base = " << b_num << "/" << b_den << "\n";
 
+#ifdef FRACTIONAL_BASE_NUMBER_FIXARRAYS
+#ifdef TIMING
+    cout << "FRACTIONAL_BASE_NUMBER_FIXARRAYS is defined" << endl;
+#endif
+#endif
     ulong ct = 0;
     B.first();
     ulong nd;
@@ -63,6 +68,40 @@ main(int argc, char **argv)
 
 /*
 Timing: (Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz)
+
+GCC 10.2.1
+
+ time ./bin 49 3 2
+arg 1: 49 == nd_max  [Max. number of digits]  default=7
+arg 2: 3 == b_num  [Numerator of basis, must be >= 2]  default=3
+arg 3: 2 == b_den  [Denominator of basis, must be < b_num]  default=2
+Base = 3/2
+FRACTIONAL_BASE_NUMBER_FIXARRAYS is defined
+ ct = 1379192733
+./bin 49 3 2  4.14s user 0.00s system 99% cpu 4.157 total
+ ==> 1379192733 / 4.14 = 333,138,341 per second
+
+ time ./bin 14 9 2
+arg 1: 14 == nd_max  [Max. number of digits]  default=7
+arg 2: 9 == b_num  [Numerator of basis, must be >= 2]  default=3
+arg 3: 2 == b_den  [Denominator of basis, must be < b_num]  default=2
+Base = 9/2
+FRACTIONAL_BASE_NUMBER_FIXARRAYS is defined
+ ct = 3187184562
+./bin 14 9 2  4.55s user 0.00s system 99% cpu 4.550 total
+ ==> 3187184562 / 4.55 == 700,480,123 per second
+
+ time ./bin 31 2 1 # binary numbers
+arg 1: 31 == nd_max  [Max. number of digits]  default=7
+arg 2: 2 == b_num  [Numerator of basis, must be >= 2]  default=3
+arg 3: 1 == b_den  [Denominator of basis, must be < b_num]  default=2
+Base = 2/1
+FRACTIONAL_BASE_NUMBER_FIXARRAYS is defined
+ ct = 2147483648
+./bin 31 2 1  5.44s user 0.00s system 99% cpu 5.439 total
+ ==> 2147483648 / 5.44 == 394,758,023 per second
+
+
 GCC 8.3.0
 
 // with FRACTIONAL_BASE_NUMBER_FIXARRAYS defined:
